*******************************************************************************************************************************
*******************************************************************************************************************************

// Generate basic sample file
// 01_BasicSample.do

***********************************************

/*
Using the RAND Family File and the RAND HRS file (respondent level file), we generate the baseline sample
and the analytical sample.

The analytical sample contains families in which we observe at least one adult child experiencing 
the transition to parental care.

This transition is defined as follows:
- Parents (= respondents) are observed at least at two points in time.
- Parents did not receive help with ADLs in the first wave(s) of observation 
 (observation window starting at wave 4).
- Parents received help with ADLs from at least one child at some later point in time.

The basic sample only contains persons who participated continuously and don't have 
missing data in the transfer indicators generated by RAND. More detailed information 
on the sample construction are reported below and are stored in the log file 
"SampleSizeMonitor" (log-folder).

The file "02_AnalyticalSample" stored in the "posted" folder is a dyadic dataset:
- Every observation represents one parent-child dyad
- All explanatory variables are from the year before we observe the actual care transition.

Caveat: 
The process is left censored. We cannot determine with absolute certainty that we observe 
the initial transition to parent care. Hence, we generate a smaller subsample
for robustness checks:
	
	The subsample contains only parents who did not receive help in the first 
	two (or more) years of observation (i.e., previous transitions to parent care are very unlikely)
	
*/

*******************************************************************************************************************************
*******************************************************************************************************************************

//Generate dataset keeping only the required variables
//using RAND HRS and RAND family file

***********************************************

//Use the RAND HRS File to retrieve some 
//respondent level (= parent) variables 

clear 
tempfile aux 

use hhidpn r?famr rabyear r?agey_b ragender raracem rahispan raedyrs raeduc ///
r?mstat r?mpart r?mobila r?lgmusa r?adla r?lifta r?dimea r?armsa ///
r?iadlza r?iadla using "${HRS}/01_RAND/rndhrs_l", clear

save `aux', replace


***********************************************

//Use the RAND Family File to generate our analytic sample

use "${HRS}/02_RAND_Family/rndfamk_b.dta", clear 


***********************************************

//keep only the required variables 

keep hhidpn hhid hacohort kidid krrel inw? k?alive k?hlpadl ///
k?hlpiadl k?hlpfin k?fcany k?tcany ///
kabyearbg k?agebg kagenderbg k?mstat kaeduc k?nkid k?gkids ///
k?contyr k?liv10 k?resd k?work k?hlpfut ///
k?kdcare k?will k?lfins k?deed k?hmdeed k?ownrhm

order hhidpn hhid hacohort kidid krrel inw? k?alive k?hlpadl ///
k?hlpiadl k?hlpfin k?fcany k?tcany ///
kabyearbg k?agebg kagenderbg k?mstat kaeduc k?nkid k?gkids ///
k?contyr k?liv10 k?resd k?work k?hlpfut ///
k?kdcare k?will k?lfins k?deed k?hmdeed k?ownrhm


***********************************************

//merge children to respondents

merge m:1 hhidpn using `aux', keep(3) nogen


***********************************************

//rename the variables for reshape

rename k#alive kalive#
rename k#hlpadl khlpadl#
rename k#hlpiadl khlpiadl#
rename k#hlpfin khlpfin#
rename k#fcany kfcany#
rename k#tcany ktcany#
rename k#agebg kagebg#
rename k#mstat kmstat#
rename k#nkid knkid#
rename k#gkids kgkids#
rename k#contyr kcontyr#
rename k#liv10 kliv#
rename k#resd kresd#
rename k#work kwork#
rename k#hlpfut khlpfut#
rename k#kdcare kdcare#
rename k#will kwill#
rename k#lfins klfins# 
rename k#deed kdeed#
rename k#hmdeed khmdeed# 
rename k#ownrhm kownrhm#

rename r#famr rfamr#
rename r#agey_b ragey#
rename r#mstat rmstat# 
rename r#mpart rmpart# 
rename r#lifta rlifta#
rename r#dimea rdimea#
rename r#armsa rarmsa#
rename r#mobila rmobila#
rename r#lgmusa rlgmusa#
rename r#adla radla#
rename r#iadlza riadlza#
rename r#iadla riadla#


***********************************************

//rehshape to long format:
//each line represents a "child year"

reshape long inw rfamr ragey rmstat rmpart rlifta rdimea rarmsa ///
rmobila rlgmusa radla riadlza riadla kalive khlpadl khlpiadl 	///
khlpfin kfcany kagebg kmstat knkid kgkids kcontyr kliv kresd 	///
kwork khlpfut kdcare ktcany kwill klfins kdeed khmdeed kownrhm, ///
i(hhidpn kidid) j(wave)


***********************************************

label var wave 		"Wave indicator - RAND Numbering"
label var khlpadl 	"Dummy - ADL help from child"
label var khlpiadl 	"Dummy - IADL help from child"
label var khlpfin	"Dummy - Help with finances from child"
label var kfcany 	"Dummy - Financial transfer from child" 
label var ktcany 	"Dummy - Financial transfer to child" 
label var kagebg 	"Child's age (RAND - best guess)"
label var kmstat 	"Child's marital status"
label var knkid 	"Number of child's children"
label var kgkids 	"Number of child's grandchildren"
label var kcontyr 	"Contact frequency with child"
label var kliv 		"Dummy - child lives within 10 miles"
label var kresd 	"Coresiding child?"
label var kwork 	"Child's employment status"
label var khlpfut 	"Child's expected to help in future" 
label var kdcare 	"Dummy - Child receives help with child care"
label var kwill 	"Dummy - Child included in resp's will"
label var klfins 	"Dummy - Child's beneficiary of life insurance"
label var kdeed 	"Dummy - Child received a deed to a house from resp"
label var khmdeed 	"Dummy - Child on home deed (housing section)"
label var kownrhm 	"Dummy - Child owns resp's house (resp section)" 
label var ragey 	"Respondent's age at interview"
label var rmstat 	"Respondent's marital status"
label var rmpart 	"Dummy - Respondent partnered"
label var rlifta	"R Some Diff-Lift/carry 10lbs"
label var rdimea	"R Some Diff-Pick up a dime"
label var rarmsa	"R Some Diff-Rch/xtnd arms up"
label var rlgmusa	"Respondent has difficulties with large muscles"
label var rmobila	"Respondent has difficulties with mobility"
label var radla 	"Respondent has difficulties with ADLs"
label var riadla 	"Respondent has difficulties with IADLs /0-3"
label var riadlza 	"Respondent has difficulties with IADLs /0-5"


*******************************************************************************************************************************
*******************************************************************************************************************************

******************************************
//Generate analytical sample and variables
******************************************

***********************************************

//Indicator for first year of participation

gen aux = wave if inw == 1
bysort hhidpn (kidid wave): egen realfirstwave = min(aux)
label var realfirstwave "First wave respondent participated in HRS (wo censoring)"
drop aux

***********************************************

//drop waves before transfer indicators are available
//The RAND family file provides information on transfers starting with wave 4

drop if wave < 4


***********************************************

//generate wave indicators 

gen aux = wave if inw == 1
bysort hhidpn (kidid wave): egen firstwave = min(aux)
label var firstwave "First wave respondent participated in HRS (min set to 4)"
bysort hhidpn (kidid wave): egen lastwave = max(aux)
drop aux


***********************************************

//Drop persons who did not participate in wave 4 or later
/*Note:
* the reshape command assumes a balanced panel design, i.e. every
  person is expected to be surveyed in every wave; consequently
  reshape generates records (=rows) even for years in which a person
  did not participate in the study
* firstwave = . for persons who did not participate in wave 4+;
  "drop if firstwave == ." removes these persons; this is necessary 
  because we do not have any information on transfer indicators for 
  these persons
*/

drop if firstwave == .


***********************************************
***********************************************

//Sample Size Monitoring

*indicator for counting number of unique parent-child dyads
*auxDyads equals 1 for the first observation of each parent-child dyad
*using this variable ensures that each dyad is counted only once
bysort hhidpn kidid (wave): gen auxDyads = _n == 1

qui distinct hhidpn
global samplesizeRespBS `r(ndistinct)'
qui count if auxDyads == 1
global samplesizeDyadsBS `r(N)'
drop auxDyads

qui {
	log using "${log}/SampleSizeMonitor", replace text
	noisily dis _newline "#################################"
	noisily dis "Size of starting sample:" 
	noisily dis "Persons with at least one child participating "
	noisily dis "at least once since wave 4" 
	noisily dis "	Number of respondents: ${samplesizeRespBS}"
	noisily dis "	Number of parent-child dyads: ${samplesizeDyadsBS}"
	noisily dis "#################################"
	log close
	}
	

***********************************************
***********************************************

//First selection: Within-family study of care selection requires at least 2 children per family
//-- >Drop persons with less than 2 living children

drop if krrel == 6 // kids in-law are removed*

/*
*Inlaws are removed because...
	.. some variables are only available for own children and/or 
	   for some variables the number of missings is extremely high for in-laws
	.. in contrast to own children inlaws are not fixed over time 
*/


***********************************************

//Running Number for kids
//+ indicator counting the number of children in data for each respondent
//(this indicator might be different from the number of kids indicator
//which is stored in the RAND respondent level family file
//see selection 5: here we crossvalidate the two "kid number"-indicators

bysort hhidpn wave (kidid): gen kidnr = _n
bysort hhidpn wave (kidid): gen kidsindata = _N

drop if kidsindata == 1 // exclude families with only 1 child


***********************************************

//Sample size after first selection 

*indicator for counting number of unique parent-child dyads
bysort hhidpn kidid (wave): gen auxDyads = _n == 1

qui distinct hhidpn
global samplesizeRespAS `r(ndistinct)'
qui count if auxDyads == 1
global samplesizeDyadsAS `r(N)'
drop auxDyads

local reductionRespAbs = ${samplesizeRespBS} - ${samplesizeRespAS}
local reductionRespRel = round(((1 - ${samplesizeRespAS}/${samplesizeRespBS})*100),.01)

local reductionDyadsAbs = ${samplesizeDyadsBS} - ${samplesizeDyadsAS}
local reductionDyadsRel = round(((1 - ${samplesizeDyadsAS}/${samplesizeDyadsBS})*100),.01)


qui {
	log using "${log}/SampleSizeMonitor", append text
	noisily dis _newline "#################################"
	noisily dis "Selection 1: Drop persons with less than 2 children"
	noisily dis "	Number of respondents:" 
	noisily dis "		Was: ${samplesizeRespBS}; Is: ${samplesizeRespAS}"
	noisily dis "		--> dropping `reductionRespAbs' respondents; reduction by `reductionRespRel'%" 
	noisily dis "	Number of Dyads:" 
	noisily dis "		Was: ${samplesizeDyadsBS}; Is: ${samplesizeDyadsAS}"
	noisily dis "		--> dropping `reductionDyadsAbs' dyads; reduction by `reductionDyadsRel'%"
	noisily dis "#################################"
	log close
	}

//Update sample size indicators	
global samplesizeRespBS = ${samplesizeRespAS}
global samplesizeDyadsBS = ${samplesizeDyadsAS}


***********************************************
***********************************************

//Second Selection
//keep only persons with at least two waves of observation

/*Note:
* the reshape command assumes a balanced panel design, i.e. every
  person is expected to be surveyed in every wave; consequently
  reshape generates records (=rows) even for years in which a person
  did not participate in the study: "drop if wave < firstwave | wave > lastwave"
  deletes these "useless" lines 
*/

drop if wave < firstwave | wave > lastwave

//studying the transition to care requires at least two years
//of observation; persons who participated only in one wave are removed
drop if (lastwave - firstwave) < 1

***********************************************

//Sample size after second selection 

*indicator for counting number of unique parent-child dyads
bysort hhidpn kidid (wave): gen auxDyads = _n == 1

qui distinct hhidpn
global samplesizeRespAS `r(ndistinct)'
qui count if auxDyads == 1
global samplesizeDyadsAS `r(N)'
drop auxDyads

local reductionRespAbs = ${samplesizeRespBS} - ${samplesizeRespAS}
local reductionRespRel = round(((1 - ${samplesizeRespAS}/${samplesizeRespBS})*100),.01)

local reductionDyadsAbs = ${samplesizeDyadsBS} - ${samplesizeDyadsAS}
local reductionDyadsRel = round(((1 - ${samplesizeDyadsAS}/${samplesizeDyadsBS})*100),.01)


qui {
	log using "${log}/SampleSizeMonitor", append text
	noisily dis _newline "#################################"
	noisily dis "Selection 2: Drop person who participated only in one wave"
	noisily dis "	Number of respondents:" 
	noisily dis "		Was: ${samplesizeRespBS}; Is: ${samplesizeRespAS}"
	noisily dis "		--> dropping `reductionRespAbs' respondents; reduction by `reductionRespRel'%" 
	noisily dis "	Number of Dyads:" 
	noisily dis "		Was: ${samplesizeDyadsBS}; Is: ${samplesizeDyadsAS}"
	noisily dis "		--> dropping `reductionDyadsAbs' dyads; reduction by `reductionDyadsRel'%"
	noisily dis "#################################"
	log close
	}

//Update sample size indicators	
global samplesizeRespBS = ${samplesizeRespAS}
global samplesizeDyadsBS = ${samplesizeDyadsAS}


***********************************************
***********************************************

//Third Selection
//Keep only persons for whom we observe the care transition

***********************************************

//Set help indicator to 0 if respondent does not require help
//radla = 0: respondent does not need help with adl

replace khlpadl = 0 if radla == 0 & missing(khlpadl)

//the ADL questions were not asked if the respondent didn't
//report any difficulties with activities like getting up from a chair;
//if respondent didn't report any difficulties with these activities
//we assume that she did not receive ADL help (only for those cases 
//who still have a missing on "khlpadl")

foreach var of varlist rarmsa rlifta rdimea rmobila rlgmusa {
	replace `var' = 99 if missing(`var')
	}

egen 	auxHealth = rowtotal(rarmsa rlifta rdimea rmobila rlgmusa)	
replace auxHealth = auxHealth == 0

replace khlpadl = 0 if auxHealth == 1 & missing(khlpadl)

drop auxHealth rarmsa rlifta rdimea rmobila rlgmusa

***********************************************

//keep only families in which parents didn't receive help in the first wave of observation

gen aux = inlist(khlpadl,1,.,.d,.r) & wave == firstwave
bysort hhidpn (kidid wave): egen nohelpfirstwave = max(aux)
drop if nohelpfirstwave == 1
drop aux nohelpfirstwave

***********************************************

//keep only families in which parents receive help in 
//the second year of observation or later

***

gen aux = wave if khlpadl == 1
bysort hhidpn (kidid wave): egen parrechlpfirst = min(aux)

***

//drop families without care transition (parrechlpfirst == .)
//drop years after the transition (wave > parrechlpfirst; this does 
//not affect the sample size) 

drop if parrechlpfirst == . | wave > parrechlpfirst 
drop aux 

//the "new" last wave is the wave in which we observe the transition 
replace lastwave = parrechlpfirst  
drop parrechlpfirst

***********************************************

//Sample size after third selection 

*indicator for counting number of unique parent-child dyads
bysort hhidpn kidid (wave): gen auxDyads = _n == 1

qui distinct hhidpn
global samplesizeRespAS `r(ndistinct)'
qui count if auxDyads == 1
global samplesizeDyadsAS `r(N)'
drop auxDyads

local reductionRespAbs = ${samplesizeRespBS} - ${samplesizeRespAS}
local reductionRespRel = round(((1 - ${samplesizeRespAS}/${samplesizeRespBS})*100),.01)

local reductionDyadsAbs = ${samplesizeDyadsBS} - ${samplesizeDyadsAS}
local reductionDyadsRel = round(((1 - ${samplesizeDyadsAS}/${samplesizeDyadsBS})*100),.01)


qui {
	log using "${log}/SampleSizeMonitor", append text
	noisily dis _newline "#################################"
	noisily dis "Selection 3 (Baseline sample): Keep only persons with observed care transition"
	noisily dis "	Number of respondents:" 
	noisily dis "		Was: ${samplesizeRespBS}; Is: ${samplesizeRespAS}"
	noisily dis "		--> dropping `reductionRespAbs' respondents; reduction by `reductionRespRel'%" 
	noisily dis "	Number of Dyads:" 
	noisily dis "		Was: ${samplesizeDyadsBS}; Is: ${samplesizeDyadsAS}"
	noisily dis "		--> dropping `reductionDyadsAbs' dyads; reduction by `reductionDyadsRel'%"
	noisily dis "#################################"
	log close
	}

//Update sample size indicators	
global samplesizeRespBS = ${samplesizeRespAS}
global samplesizeDyadsBS = ${samplesizeDyadsAS}

***********************************************
***********************************************

//Save baseline sample for comparison with analysis sample

save "${posted}/01_BaselineSample", replace

***********************************************
***********************************************

//Fourth selection
//only keep persons who participate (quite) continuously
//and without missing data on the key outcome (i.e., the ADL indicator)

***

//participating continuously
//definition: no missing observation in the two years before
//the transition to care occurs

gen aux = wave if inw == 0
bysort hhidpn (kidid wave): egen aux2 = max(aux)

gen missingwave = (lastwave - aux2) < 3 & !missing(aux2)

drop if missingwave == 1
drop aux aux2 missingwave 

***

//No problems with ADL indicator
//procedure analogous to previous selection

gen aux = wave if khlpadl == .
bysort hhidpn (kidid wave): egen aux2 = max(aux)

gen adlproblem = (lastwave - aux2) < 3 & !missing(aux2)


drop if adlproblem == 1
drop aux aux2 adlproblem


***********************************************

//Sample size after fourth selection 

*indicator for counting number of unique parent-child dyads
bysort hhidpn kidid (wave): gen auxDyads = _n == 1

qui distinct hhidpn
global samplesizeRespAS `r(ndistinct)'
qui count if auxDyads == 1
global samplesizeDyadsAS `r(N)'
drop auxDyads

local reductionRespAbs = ${samplesizeRespBS} - ${samplesizeRespAS}
local reductionRespRel = round(((1 - ${samplesizeRespAS}/${samplesizeRespBS})*100),.01)

local reductionDyadsAbs = ${samplesizeDyadsBS} - ${samplesizeDyadsAS}
local reductionDyadsRel = round(((1 - ${samplesizeDyadsAS}/${samplesizeDyadsBS})*100),.01)


qui {
	log using "${log}/SampleSizeMonitor", append text
	noisily dis _newline "#################################"
	noisily dis "Selection 4: Keep persons who participate continuously"
	noisily dis "			  and without problems with ADL indicator"
	noisily dis "	Number of respondents:" 
	noisily dis "		Was: ${samplesizeRespBS}; Is: ${samplesizeRespAS}"
	noisily dis "		--> dropping `reductionRespAbs' respondents; reduction by `reductionRespRel'%" 
	noisily dis "	Number of Dyads:" 
	noisily dis "		Was: ${samplesizeDyadsBS}; Is: ${samplesizeDyadsAS}"
	noisily dis "		--> dropping `reductionDyadsAbs' dyads; reduction by `reductionDyadsRel'%"
	noisily dis "#################################"
	log close
	}

//Update sample size indicators	
global samplesizeRespBS = ${samplesizeRespAS}
global samplesizeDyadsBS = ${samplesizeDyadsAS}


***********************************************
***********************************************

//generate indicator for robustness check 
	*keep if robustcheck == 1
	*use only families in which parents didn't receive help 
	*in the first two years of observation

bysort hhidpn kidid (wave): gen robustcheck = _N
replace robustcheck = robustcheck > 2
label var robustcheck "Dummy - Two (or more) years without help"


***********************************************

//keep only two lines for each parent-child dyad
//i.e. year before help + year of help

keep if (wave == lastwave) | (wave == (lastwave - 1))
drop lastwave inw //drop unnecessary variables


***********************************************
***********************************************

//Fifth selection
//Drop respondents with "missing children"; i.e., number of children stated by the respondent might
//differ from number of children included in the dyadic data

//Add "number of children"-indicator 
//from respondent level family file
//for comparison with number of children
//in the dyadic dataset

preserve

use "${HRS}/02_RAND_Family/rndfamr_b", clear 
keep hhidpn h?child 

rename h#child hchild#
reshape long hchild, i(hhidpn) j(wave)

tempfile aux
save `aux', replace

restore


***********************************************

//Drop respondents with "missing children"
//missing children: number of kids reported 
//in respondent level file (variable "hchild") > number
//of kids in dyadic dataset (variable "kidsindata")

merge m:1 hhidpn wave using `aux', keep(1 3) nogen

gen aux = kidsindata - hchild
bysort hhidpn (wave kidnr): egen aux2 = min(aux) 
drop if aux2 < 0 
drop aux aux2


***********************************************

//Sample size after fifth selection 

*indicator for counting number of unique parent-child dyads
bysort hhidpn kidid (wave): gen auxDyads = _n == 1

qui distinct hhidpn
global samplesizeRespAS `r(ndistinct)'
qui count if auxDyads == 1
global samplesizeDyadsAS `r(N)'
drop auxDyads

local reductionRespAbs = ${samplesizeRespBS} - ${samplesizeRespAS}
local reductionRespRel = round(((1 - ${samplesizeRespAS}/${samplesizeRespBS})*100),.01)

local reductionDyadsAbs = ${samplesizeDyadsBS} - ${samplesizeDyadsAS}
local reductionDyadsRel = round(((1 - ${samplesizeDyadsAS}/${samplesizeDyadsBS})*100),.01)


qui {
	log using "${log}/SampleSizeMonitor", append text
	noisily dis _newline "#################################"
	noisily dis "Selection 5: Only keep persons reporting on all"
	noisily dis "			  of their children"
	noisily dis "	Number of respondents:" 
	noisily dis "		Was: ${samplesizeRespBS}; Is: ${samplesizeRespAS}"
	noisily dis "		--> dropping `reductionRespAbs' respondents; reduction by `reductionRespRel'%" 
	noisily dis "	Number of Dyads:" 
	noisily dis "		Was: ${samplesizeDyadsBS}; Is: ${samplesizeDyadsAS}"
	noisily dis "		--> dropping `reductionDyadsAbs' dyads; reduction by `reductionDyadsRel'%"
	noisily dis "#################################"
	log close
	}

//Update sample size indicators	
global samplesizeRespBS = ${samplesizeRespAS}
global samplesizeDyadsBS = ${samplesizeDyadsAS}


***********************************************
***********************************************

//Sixth Selection
//Drop respondents with less than two
//children after excluding dead children 
//and children that are under 18 
//(some variables are only available if the children are 18 or older)

drop if kalive == 0
drop if kagebg < 18


//Update kidnr kidsindata

drop kidnr kidsindata
bysort hhidpn wave (kidid): gen kidnr = _n
bysort hhidpn wave (kidid): gen kidsindata = _N

drop if kidsindata == 1


//all children should be in the dataset with two records (balanced design):
//	*record 1: year before care selection
//  *record 2: year of transition to care

bysort hhidpn kidid (wave): gen duration = _N
bysort hhidpn (kidid wave): egen durmin = min(duration)
bysort hhidpn (kidid wave): egen durmax = max(duration)

distinct hhidpn
drop if durmin != durmax
distinct hhidpn

drop duration durmin durmax

//keep only respondents with two years of observation
//Note: due to the previous selections it is possible
//		that some families are observed only for one year
//		(example: in the first year of observation all
//		children were younger than 18; consequently, we have
//		only one observation for these families --> drop)

bysort hhidpn kidid (wave): gen aux = _N
bysort hhidpn (kidid wave): egen aux2 = min(aux)
drop if aux2 == 1
drop aux aux2

***********************************************

//outcome variable - parent receives help with ADL from at least one adult child:
//insert value of observation at time 2 for both years of observation
	*for the models with lagged covariates, use obs == 1
	*for cross-sectional models (cave: endogeneity!), use obs == 2

bysort hhidpn kidid (wave): gen outcome = khlpadl[2]

*Due to previous selection there are a few cases without care transition -> drop
bysort hhidpn (kidid): egen aux = total(outcome)
drop if aux == 0
drop aux

***********************************************


//Sample size after sixth selection 

*indicator for counting number of unique parent-child dyads
bysort hhidpn kidid (wave): gen auxDyads = _n == 1

qui distinct hhidpn
global samplesizeRespAS `r(ndistinct)'
qui count if auxDyads == 1
global samplesizeDyadsAS `r(N)'
drop auxDyads

local reductionRespAbs = ${samplesizeRespBS} - ${samplesizeRespAS}
local reductionRespRel = round(((1 - ${samplesizeRespAS}/${samplesizeRespBS})*100),.01)

local reductionDyadsAbs = ${samplesizeDyadsBS} - ${samplesizeDyadsAS}
local reductionDyadsRel = round(((1 - ${samplesizeDyadsAS}/${samplesizeDyadsBS})*100),.01)


qui {
	log using "${log}/SampleSizeMonitor", append text
	noisily dis _newline "#################################"
	noisily dis "Selection 6: Only keep persons with two or more LIVING"
	noisily dis "			  children during the transition"
	noisily dis "	Number of respondents:" 
	noisily dis "		Was: ${samplesizeRespBS}; Is: ${samplesizeRespAS}"
	noisily dis "		--> dropping `reductionRespAbs' respondents; reduction by `reductionRespRel'%" 
	noisily dis "	Number of Dyads:" 
	noisily dis "		Was: ${samplesizeDyadsBS}; Is: ${samplesizeDyadsAS}"
	noisily dis "		--> dropping `reductionDyadsAbs' dyads; reduction by `reductionDyadsRel'%"
	noisily dis "#################################"
	log close
	}

//Update sample size indicators	
global samplesizeRespBS = ${samplesizeRespAS}
global samplesizeDyadsBS = ${samplesizeDyadsAS}


*******************************************************************************************************************************
*******************************************************************************************************************************

//Wave indicator: 
	*1 = year before care transition
	*2 = year of transition

bysort hhidpn kidid (wave): gen obs = _n


*******************************************************************************************************************************
*******************************************************************************************************************************

//explanatory variables - child characteristics measured at t1
//generate & recode variables &
//drop dispensable variables

***********************************************

//biological relation to respondent

gen aux = krrel
drop krrel

recode aux (2 = 0 "stepchild") (1 = 1 "own child"), gen(krrel) 
drop aux


***********************************************

//child's age

drop kabyearbg 

rename kagebg kage 
gen kage_miss = kage == .m //missing flag*
replace kage = 99 if kage == .m

/*
*missing flag:
	Note that we recode all missings to "valid values" (usually code 99);
	in addition, we create missing flags (var_miss) for every covariate.
	This procedure avoids listwise deletion of dyads with missing
	values; moreover, including the missing categories in the regression models
	gains a better understanding of the process leading to missing values
	
	If the regression results with and without listwise deletion produce similar
	results we choose the more parsimonious model with listwise deletion

	Using the missing flags we can easily change missing values into numeric 
	values, and vice versa

*/

***********************************************

//child's gender

gen kfemale = kagenderbg == 2
drop kagenderbg

label define dummy ///
99 "missing" 0 "no" 1 "yes"

label var 	 kfemale "Dummy - Daughter"
label values kfemale dummy


***********************************************

//child married or partnered

gen kcouple = inlist(kmstat,1,2) //kmstat has no missings
label var kcouple "Dummy - Child has partner/is married"

gen ksingle = kcouple == 0
label var ksingle "Dummy - Child has no partner/is not married"


label values kcouple ksingle dummy

***********************************************

//number of child's children

//Replace missing for re-interviewed households
	//for some waves variable was not asked in re-interviewed households
	//for these cases RAND assings the missing value ".y"
	//with the following loop we replace this missing with the value reported 
	//in the previous wave (`x' - 1); 

merge m:1 hhidpn kidid using "${HRS}/02_RAND_Family/rndfamk_b.dta", ///
keepusing(k?nkid) keep(1 3) nogen

forvalues x = 4/9 { //our observation period covers wave 4 to 9
	local y = `x' - 1
	replace knkid = k`y'nkid if knkid == .y & !missing(k`y'nkid)
	}

drop k?nkid
	
***

//center variable groupwise by family
	//for a more convenient interpretation of the
	//the within family regression results
	
capt ssc install center //install ado if necessary

bysort hhidpn (kidid): center knkid, ///
gen(knkid_c) addtolabel(" (centered - family mean)")

***

//Dummy: child has children
generate khaskid = knkid != 0
replace  khaskid = 99 if missing(knkid)
generate khaskid_miss = khaskid == 99

label var khaskid "Dummy - Child has at least one child"
label values khaskid dummy

***

//Dummy: child's number of children above family average

qui sum knkid_c if knkid_c > 0
generate knkid_within = inrange(knkid_c,`r(min)',`r(max)')
replace  knkid_within = 99 if knkid_c == .

label var knkid_within "Dummy - Child's number of children above family average"
label values knkid_within dummy

gen knkid_within_miss = knkid_within == 99

***

generate knkid_miss = missing(knkid) //backup missing indicator
replace  knkid = 99 if missing(knkid) 

***

generate knkid_c_miss = missing(knkid_c) //backup missing indicator
replace  knkid_c = 99 if missing(knkid_c)


***********************************************

//child has own children

//replacing some missings with information from previous wave
//procedure analogous to "knkid"

merge m:1 hhidpn kidid using "${HRS}/02_RAND_Family/rndfamk_b.dta", ///
keepusing(k?gkids) keep(1 3) nogen

forvalues x = 4/9 {
	local y = `x' - 1
	replace kgkids = k`y'gkids if kgkids == .y & !missing(k`y'gkids)
	}

drop k?gkids	
	
generate kgrandkid = inrange(kgkids,1,50)
replace  kgrandkid = kgkids if kgkids > 50
replace  kgrandkid = 0 if knkid == 0 //if there is no child there can't be a grandchild

replace  kgrandkid = 99 if kgkids > 50
generate kgrandkid_miss = kgrandkid == 99 //backup missing indicator


label values kgrandkid dummy
label var kgrandkid "Child has gandchild"
 

***********************************************

//contact frequency

merge m:1 hhidpn kidid using "${HRS}/02_RAND_Family/rndfamk_b.dta", ///
keepusing(k?contyr) keep(1 3) nogen

forvalues x = 4/9 {
	local y = `x' - 1
	replace kcontyr = k`y'contyr if kcontyr == .y & !missing(k`y'contyr)
	}

drop k?contyr	
	
replace kcontyr = 365 if kcontyr == .l //.l = coresident child = daily contact


gen aux = kcontyr
replace aux = 365 if aux > 365 & !missing(aux) //top coding for out-of-range values

//Note: 313-365 "virtually daily" = more than 6 times a week (6*52 = 312)
recode aux (0/51 = 1 "less than once a week") (52/312 = 2 "at least once a week") ///
(313/365 = 3 "virtually every day") (./.z = 99 "missing"), gen(kcontact)

generate kcontact_miss = kcontact == 99 //backup missing indicator

drop aux


***********************************************
 
//proximity: child lives within 10 miles

recode kliv (.l = 0 "coresidence") (1 = 1 "within 10 miles (no coresidence)") ///
(0 = 2 "more than 10 miles")  (.c/.m = 99 "missing"), gen(kdist)

generate kdist_miss = kdist == 99 //backup missing indicator


***********************************************

//years of education

generate keduyears = kaeduc

//center variable groupwise by family
bysort hhidpn (kidid): center keduyears, ///
gen(keduyears_c) addtolabel(" (centered - family mean)")

replace  keduyears 	 = 99 if missing(kaeduc)
replace  keduyears_c = 99 if missing(kaeduc)

gen keduyears_miss = missing(kaeduc)
gen keduyears_c_miss = missing(kaeduc)


***********************************************

//employment status

gen aux = kwork
drop kwork

recode aux (0 .a = 0 "not working") (1 = 1 "work pt") ///
(2 = 2 "work ft") (.a/.s = 99 "missing"), gen(kwork)

label var kwork "Child's employment status"
drop aux

gen kwork_miss = kwork == 99 //backup missing indicator

gen 	kwork2 = kwork
replace kwork2 = 1 if kwork == 2

label var kwork2 "Dummy - Child working - yes/no"
label values kwork2 dummy

gen kwork2_miss = kwork2 == 99 //backup missing indicator


***********************************************

//IADL help
//include help with finances 
//(that's in line with the corresponding parental 
// need indicator which also includes "finances")

replace  khlpiadl = 1 if khlpfin == 1
replace  khlpiadl = 99 if khlpiadl == .
generate khlpiadl_miss = khlpiadl == 99 //backup missing indicator

label values khlpiadl dummy


***********************************************

//Financial transfer to child

replace  ktcany = 99 if missing(ktcany) 
generate ktcany_miss = ktcany == 99

label values ktcany dummy

 
***********************************************

//Child receives help with child care

replace  kdcare = 99 if missing(kdcare)
generate kdcare_miss = kdcare == 99

label values kdcare dummy

***********************************************

//respondent expects help from child in future

gen kfuturehelp = khlpfut
replace kfuturehelp  = 99 if missing(kfuturehelp) 

label values kfuturehelp dummy

gen kfuturehelp_miss = kfuturehelp == 99 //backup missing indicator


***********************************************

//birth order

gen aux = kage if obs == 1 //age at first observation

//sort children by age (within families)
//in descending order: 
//--> oldest child (kbirthorder == 1) is first record 
gsort  +hhidpn -aux, gen(aux2) 
bysort hhidpn (aux2): gen kbirthorder = _n if aux !=.
drop aux aux2

//Note that until now kbirthorder has only valid values
//for the first year of observation --> use observation 1 value also for observation 2
bysort hhidpn kidid (obs): replace kbirthorder = kbirthorder[1]

//set variable to missing for dyads with missing age information
replace kbirthorder = . if kage == 99

//Dummies for fistborn and lastborn child
//children with missng information on age are not considered 
//note that there are hardly any missings on age (=14)
bysort hhidpn (kbirthorder obs): egen aux = min(kbirthorder)
gen kfirstborn = kbirthorder == aux & kbirthorder != .
drop aux

bysort hhidpn (kbirthorder obs): egen aux = max(kbirthorder)
gen klastborn = kbirthorder == aux & kbirthorder != .
drop aux 

//backup missing indicator; recode missings to valid values
foreach var of varlist kfirstborn klastborn kbirthorder {
	replace `var' = 99 if kage == 99
	gen 	`var'_miss = kage == 99
	}

label values kfirstborn klastborn dummy	
	
sort hhidpn kidid obs

***********************************************

//child included in respondent's will

*if "no will", indicator is set to 1 (i.e., all children inherit equally)
replace kwill = 1 if kwill == .b 
replace kwill = 99 if kwill > 1

label values kwill dummy

gen kwill_miss = kwill == 99 //backup missing indicator


***********************************************

//Child is Beneficiary of Life Insurance

replace klfins = 0 if klfins == .t
replace klfins = 99 if klfins > 1

label values klfins dummy

gen klfins_miss = klfins == 99 //backup missing indicator


***********************************************

//Child Received a Deed to a House from Respondent

replace kdeed = 99 if missing(kdeed)

label values kdeed dummy

gen kdeed_miss = kdeed == 99 //backup missing indicator


***********************************************

//Child on Home Deed (from Housing section)

replace khmdeed = 99 if missing(khmdeed)

label values khmdeed dummy

gen khmdeed_miss = khmdeed == 99 //backup missing indicator


***********************************************

//Child Owns Respondent's House (from Respondent Section)

replace kownrhm = 99 if missing(kownrhm)

label values kownrhm dummy

gen kownrhm_miss = kownrhm == 99 //backup missing indicator


*******************************************************************************************************************************
*******************************************************************************************************************************

//Variables for "Endogeneity" Model,
	//i.e. a cross-sectional model using only wave 2 covariates
	//to predict wave 2 outcome; allows comparison between correct 
	//model with lagged covariates and the cross-sectional 
	//model

	
local a "kage khaskid knkid_within knkid knkid_c kgrandkid kcontact kdist keduyears keduyears_c"
local b "kwork kwork2 khlpiadl ktcany kdcare kfuturehelp kfirstborn klastborn kwill klfins kdeed khmdeed kownrhm"

local vars `"`a' `b'"'

foreach x of local vars {
	bysort hhidpn kidid (wave): gen `x'_W2 = `x'[2]
	bysort hhidpn kidid (wave): gen `x'_W2_miss = `x'_miss[2] //backup missing indicator
	}

***	
	
local c "kfemale krrel kcouple ksingle" //variables without missings

foreach x of local c {
	bysort hhidpn kidid (wave): gen `x'_W2 = `x'[2]
	}

*******************************************************************************************************************************
*******************************************************************************************************************************

//Wave 2 variables for parents


foreach var of varlist ragey rmstat rmpart radla riadla riadlza {
	bysort hhidpn kidid (wave): gen `var'_W2 = `var'[2]
	}

*******************************************************************************************************************************

//Variables using information from second year of
//observation have been generated --> observation 2 can be deleted

drop if obs == 2

*******************************************************************************************************************************
*******************************************************************************************************************************

//Respondent-level indicators

***********************************************

//generate auxilary variable to ease description at
//respondent level --> Dummy equals 1 only for one line per person
//to obtain descriptives on respondent level, enter "if personlevel == 1"

bysort hhidpn (kidid): gen personlevel = _n == 1 
label var personlevel "Qualifier for respondent-level analysis"  

***********************************************

//age

//Variable: ragey
//no missings

***********************************************

//gender

recode ragender (2 = 1 "female") (1 = 0 "male"), gen(rgender)
drop ragender

*rgender has no missings

//Dummy: "Mother-daughter dyad"
gen momdaughter = kfemale==1 & rgender ==1
label var momdaughter "Dummy: Mother-daughter dyad"

//Dyad's gender constellation
generate dy_gender = kfemale==1 & rgender ==1
replace  dy_gender = 2 if kfemale==0 & rgender ==1
replace  dy_gender = 3 if kfemale==0 & rgender ==0
replace  dy_gender = 4 if kfemale==1 & rgender ==0

label define dygender ///
	1 "mother-daughter" ///
	2 "mother-son" ///
	3 "father-son" ///
	4 "father-daughter"
	
label values dy_gender dygender

//Dummy indicating samesex parent-child dyad
gen dy_samesex = inlist(dy_gender,1,3)

***********************************************

//race

generate rrace = raracem
replace  rrace = 4 if rrace == 3
replace  rrace = 3 if rrace != 2 & rahispan == 1

label define race ///
	1 "white/caucasian" ///
	2 "black/african american" ///
	3 "hispanic (white)" ///
	4 "other"

label values rrace race

*rrace has no missings
	
***********************************************
	
//marital status

recode rmstat (1 3 = 1 "partnered") (2 4 5 6 7 8 = 0 "no partner") , gen(rpartner)
recode rmstat_W2 (1 3 = 1 "partnered") (2 4 5 6 7 8 = 0 "no partner") , gen(rpartner_W2)

recode rmstat (1 2 = 1 "married") (4 5 = 2 "divorced/separated") ///
(7 = 3 "widowed") (3 = 4 "cohabiting") (8 = 5 "never married"), gen(rmarital)

recode rmstat_W2 (1 2 = 1 "married") (4 5 = 2 "divorced/separated") ///
(7 = 3 "widowed") (3 = 4 "cohabiting") (8 = 5 "never married"), gen(rmarital_W2)

drop rmstat rmstat_W2

replace rpartner = rmpart if missing(rpartner) & !missing(rmpart)
replace rpartner_W2 = rmpart_W2 if missing(rpartner_W2) & !missing(rmpart_W2)
drop rmpart rmpart_W2

*rpartner has no missings

***********************************************

//education

recode raeduc (1 = 1 "less than high school") ///
(2 3 = 2 "high school graduate") ///
(4 5 = 3 "at least some college"), gen(reduc)

drop raeduc

*reduc has no missings
 
***********************************************

//count helpers

bysort hhidpn (kidid): egen numhelpers = total(outcome)
gen primarycaregiver  = numhelpers == 1 //only one caregiver
gen multiplecaregiver = numhelpers > 1 & numhelpers < kidsindata //more than one caregiver
gen everyonecares	  = numhelpers == kidsindata //all kids care

generate carearrangement = 1 if primarycaregiver == 1
replace  carearrangement = 2 if multiplecaregiver == 1
replace  carearrangement = 3 if everyonecares == 1

recode carearrangement (1 = 1 "primary caregiver") ///
(2 3 = 2 "multiple caregivers"), gen(carearrangement2)


label define care ///
	1 "primary caregiver" ///
	2 "multiple caregivers" ///
	3 "every child is caregiver"
	
label values carearrangement care


***********************************************

//family composition
//number of sisters/brothers
//gender constellation


//count number of daughters separately for each family 
bysort hhidpn (kidid): egen fcnumsisters = total(kfemale)

//count number of sons separately for each family
gen aux = kfemale == 0
bysort hhidpn (kidid): egen fcnumbrothers = total(aux)
drop aux

gen fcsistersonly = fcnumbrothers == 0 //family with daughters only
gen fcbrothersonly = fcnumsisters == 0 //family with sons only

//Dummy indicating that respondent has either only sons or only daughters
gen fcsamesexsibship = fcsistersonly == 1 | fcbrothersonly == 1

//Family with children of both sexes
gen fcgendermix = fcsistersonly == 0 & fcbrothersonly == 0

label var fcsistersonly 	"Family comp. - only sisters"
label var fcbrothersonly 	"Family comp. - only brothers"
label var fcsamesexsibship 	"Family comp. - same sex sibship"
label var fcgendermix 		"Family comp. - gender mixed sibship"

//Dummy indicating that there is only one daughter in this family
gen aux = fcnumsisters == 1 & fcnumbrothers > 0
bysort hhidpn (kidid): egen fconlyonesis = max(aux)
drop aux

//Dummy indicating that there is only one son in this family
gen aux = fcnumsisters > 0 & fcnumbrothers == 1
bysort hhidpn (kidid): egen fconlyonebro = max(aux)
drop aux


label var fconlyonesis 	"Family comp. - only one sister"
label var fconlyonebro 	"Family comp. - only one brother"


generate gendercomposition = fcgendermix
replace  gendercomposition = 2 if fcsistersonly == 1
replace  gendercomposition = 3 if fcbrothersonly == 1

label define gendercomp ///
	1 "bro and sis" ///
	2 "only sis" ///
	3 "only bros"

label values gendercomposition gendercomp
label var gendercomposition "Gender composition"

*******************************************************************************************************************************
*******************************************************************************************************************************


//Data cleaning
//Seventh selection 


*drop parity outliers (parity >12)
drop if kidsindata > 12

*drop persons with inconsistent information on
*difficulties with ADLs; at t = 2 every respondent
*should report difficulties with ADLs
drop if radla_W2 == 0

//Sample size after seventh selection 

qui distinct hhidpn
global samplesizeRespAS `r(ndistinct)'
global samplesizeDyadsAS `r(N)'


local reductionRespAbs = ${samplesizeRespBS} - ${samplesizeRespAS}
local reductionRespRel = round(((1 - ${samplesizeRespAS}/${samplesizeRespBS})*100),.01)

local reductionDyadsAbs = ${samplesizeDyadsBS} - ${samplesizeDyadsAS}
local reductionDyadsRel = round(((1 - ${samplesizeDyadsAS}/${samplesizeDyadsBS})*100),.01)


qui {
	log using "${log}/SampleSizeMonitor", append text
	noisily dis _newline "#################################"
	noisily dis "Selection 7: Data cleaning - Removing outlier parity families and"
	noisily dis "			  respondents with inconsitent information on difficulties with ADL"
	noisily dis "	Number of respondents:" 
	noisily dis "		Was: ${samplesizeRespBS}; Is: ${samplesizeRespAS}"
	noisily dis "		--> dropping `reductionRespAbs' respondents; reduction by `reductionRespRel'%" 
	noisily dis "	Number of Dyads:" 
	noisily dis "		Was: ${samplesizeDyadsBS}; Is: ${samplesizeDyadsAS}"
	noisily dis "		--> dropping `reductionDyadsAbs' dyads; reduction by `reductionDyadsRel'%"
	noisily dis "#################################"
	log close
	}

//Update sample size indicators	
global samplesizeRespBS = ${samplesizeRespAS}
global samplesizeDyadsBS = ${samplesizeDyadsAS}

*******************************************************************************************************************************
*******************************************************************************************************************************


//Recode Missings

local a "kage khaskid knkid_within knkid knkid_c kgrandkid kcontact kdist keduyears keduyears_c"
local b "kwork kwork2 khlpiadl ktcany kdcare kfuturehelp kfirstborn klastborn kwill klfins kdeed khmdeed kownrhm"


local vars `"`a' `b'"'

foreach x of local vars {
	replace `x' = . if `x'_miss == 1
	replace `x'_W2 = . if `x'_W2_miss == 1

	}

	
*******************************************************************************************************************************
*******************************************************************************************************************************

//Save "01_BasicSample" in the posted-folder

save "${posted}/02_AnalyticalSample", replace

*******************************************************************************************************************************
*******************************************************************************************************************************

