*******************************************************************************************************************************
*******************************************************************************************************************************

//Figure 1 - CHANGE IN SELECTED CHARACTERISTICS ACROSS THE TRANSITION TO PARENT CARE
//04_graph_PercentageChange.do

*******************************************************************************************************************************
*******************************************************************************************************************************

//Open dataset

use  "${posted}/02_AnalyticalSample", clear

*******************************************************************************************************************************
*******************************************************************************************************************************

*****************************
//Data preparation for graph
*****************************

***********************************************

//Create dummies for every valid value of relevant variables

*Reciprocity 1: Child received financial transfer
gen gr_reci_W1_1 = ktcany if ktcany_miss != 1
gen gr_reci_W2_1 = ktcany_W2 if ktcany_W2_miss != 1

*Reciprocity 2: Child included in will
gen gr_reci_W1_2 = kwill if kwill_miss != 1
gen gr_reci_W2_2 = kwill_W2 if kwill_W2_miss != 1

*Reciprocity 3: Child beneficiary of life insurance
gen gr_reci_W1_3 = klfins if klfins_miss != 1
gen gr_reci_W2_3 = klfins_W2 if klfins_W2_miss != 1

*Employment status
tab kwork if kwork_miss != 1, gen(gr_kwork_W1_)
tab kwork_W2 if kwork_W2_miss != 1, gen(gr_kwork_W2_)

*Geographical distance
tab kdist if kdist_miss != 1, gen(gr_kdist_W1_)
tab kdist_W2 if kdist_W2_miss != 1, gen(gr_kdist_W2_)

*Contact frequency
tab kcontact if kcontact_miss != 1, gen(gr_kcontact_W1_)
tab kcontact_W2 if kcontact_W2_miss != 1, gen(gr_kcontact_W2_)


***********************************************

//Calculate the percentage change during care transition
//and save the results in new variables

foreach var in reci kwork kdist kcontact  {
	forvalues x = 1/3 {
		sum gr_`var'_W1_`x' if outcome == 1
		local mean_W1 = r(mean)
		sum gr_`var'_W2_`x' if outcome == 1
		local mean_W2 = r(mean)
		gen gr_`var'_delta_`x' = round((`mean_W2' - `mean_W1')/`mean_W1' *100,.1)
		}
	}

keep gr_reci_delta_1 - gr_kcontact_delta_3

***********************************************

//keep as many rows as necessary 
//to generate the graph 
//(12 values have to be displayed; + 3 empty rows for headings)

keep in 1/15

***********************************************

//generate group variable for labeling

gen group = _n
label define group ///
	1 "Received financial transfer" ///
	2 "Included in will" ///
	3 "Beneficiary of life insurance" ///
	4 " " ///
	5  "Not working" ///
	6  "Part-time" ///
	7  "Full-time" ///
	8  "" ///
	9  "Coresident" ///
	10  "<= 10 miles" ///
	11  "> 10 miles" ///
	12  " " ///
	13  "Less than once a week" ///
	14 "At least once a week" ///
	15 "Daily" ///
	16 " ", replace 

	
label values group group

***********************************************

*until now the percantage change variables are constants
*now we create a variable containing the information for all
*12 values of interest; for the three "heading rows" 
*the variable remains missing

gen var = .

local i 0

foreach var of varlist gr_reci_delta_1 - gr_reci_delta_3 {
local ++i
replace var = `var' in `i'
}


local i 4

foreach var of varlist gr_kwork_delta_1 - gr_kwork_delta_3 {
local ++i
replace var = `var' in `i'
}


local i 8

foreach var of varlist gr_kdist_delta_1 - gr_kdist_delta_3 {
local ++i
replace var = `var' in `i'
}


local i 12

foreach var of varlist gr_kcontact_delta_1 - gr_kcontact_delta_3 {
local ++i
replace var = `var' in `i'
}

***********************************************

//add a additional row for another "heading" in the graph

set obs 16
replace group = 16 if group == .

***********************************************

//generate auxiliary variable for positioning labels in a scatter plot

gen minus57 = -57

*******************************************************************************************************************************
*******************************************************************************************************************************	

//Generate and save graph

set scheme lean2 //user written scheme by Svend Juul

twoway ///
(bar var group if group <4, horizontal) ///
(bar var group if inrange(group,5,7), horizontal) /// 
(bar var group if inrange(group,9,11), horizontal) ///
(bar var group if inrange(group,12,15), horizontal) ///
(scatter group minus57 if !inlist(group,4,8,12), msymbol(i) ///
mlabel(group) mlabc(black) mlabs(small)), /// 
yscale(off) ylabel(,nogrid) ytitle("") legend(off) ///
xlabel(-40 "-40%" -20 "20%" 0 20 "20%" 40 "40%", labs(small)) xscale(range(-58 40)) ///
xtitle("Percentage change during care transition", margin(small) size(small)) xline(0, lstyle(foreground)) ///
text(4.2 -58 "{bf:Reciprocity}", placement(se) just(left) size(small)) ///
text(8.2 -58 "{bf:Employment status}", placement(se) just(left) size(small)) ///
text(12.2 -58 "{bf:Geographical distance}", placement(se) just(left) size(small)) ///
text(16.2 -58 "{bf:Contact frequency}", placement(se) just(left) size(small)) 


graph save 		"${graphs}/PercentageChange", replace
graph export 	"${graphs}/PercentageChange.png", width(2000) replace
graph export 	"${graphs}/PercentageChange.emf", replace

*******************************************************************************************************************************
*******************************************************************************************************************************
